Glossary
********
.. glossary::

   CG
       `conjugate gradient <https://en.wikipedia.org/wiki/Conjugate_gradient_method>`_

   LBFGS
        limited-memory `BFGS <https://en.wikipedia.org/wiki/Broyden%E2%80%93Fletcher%E2%80%93Goldfarb%E2%80%93Shanno_algorithm>`_

   SIGTT
       `spherical integral geometric tensor tomography <https://arxiv.org/abs/2305.07750>`_

   SAXS
        `small angle X-ray scattering <https://en.wikipedia.org/wiki/Small-angle_X-ray_scattering>`_

   SAXSTT
        `small angle X-ray scattering tensor tomography <https://journals.iucr.org/a/issues/2018/01/00/vk5021/index.html>`_

   SIRT 
        `simultaneous iterative reconstruction technique <https://bio3d.colorado.edu/imod/doc/SIRTexample.html>`_

   WAXS
        `wide angle X-ray scattering <https://en.wikipedia.org/wiki/Wide-angle_X-ray_scattering>`_

